@@ -8,9 +8,12 @@ base_seo_fields = (
     'twitter_type',
     'index',
     'follow',
+    'canonical',
     'title',
+    'og_title',
     'keywords',
     'description',
+    'og_description',
     'image',
     'width',
     'height',
