@@ -2,6 +2,7 @@ from django.contrib.sitemaps import Sitemap
 from django.db.models import Q
 from django.utils.timezone import now
 
+from .const import MATCH_EXACT
 from .models.url_based import UrlSeo
 from .settings import (
     SEO_URL_SEO_SITEMAP_PRIORITY,
@@ -21,6 +22,9 @@ class UrlSeoSitemap(Sitemap):
         return list(
             UrlSeo
             .objects
+            .filter(
+                match_type=MATCH_EXACT
+            )
             .exclude(
                 Q(index='noindex') |
                 Q(follow='nofollow')
@@ -28,8 +32,8 @@ class UrlSeoSitemap(Sitemap):
             .values_list('url', flat=True)
         )
 
-    def location(self, obj):
-        return obj
+    def location(self, item):
+        return item
 
     def lastmod(self, item):
         return now()
